Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(491)

Unified Diff: third_party/WebKit/Source/core/html/HTMLFormControlElement.h

Issue 2546063002: Rename FormAssociatedElement to ListedElement (Closed)
Patch Set: Rename FormAssociatedElement to ListedElement Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/HTMLFormControlElement.h
diff --git a/third_party/WebKit/Source/core/html/HTMLFormControlElement.h b/third_party/WebKit/Source/core/html/HTMLFormControlElement.h
index 10166170ff1059df22f14505600e8947336c423f..a8239a463179b4f08b217eeaac1aa44ab082b340 100644
--- a/third_party/WebKit/Source/core/html/HTMLFormControlElement.h
+++ b/third_party/WebKit/Source/core/html/HTMLFormControlElement.h
@@ -26,8 +26,8 @@
#define HTMLFormControlElement_h
#include "core/CoreExport.h"
-#include "core/html/FormAssociatedElement.h"
#include "core/html/LabelableElement.h"
+#include "core/html/ListedElement.h"
namespace blink {
@@ -40,10 +40,10 @@ enum CheckValidityEventBehavior {
};
// HTMLFormControlElement is the default implementation of
// FormAssociatedElement, and form-associated element implementations should use
tkent 2016/12/02 13:24:37 form-associated element implementations -> listed
// HTMLFormControlElement unless there is a special reason.
class CORE_EXPORT HTMLFormControlElement : public LabelableElement,
- public FormAssociatedElement {
+ public ListedElement {
USING_GARBAGE_COLLECTED_MIXIN(HTMLFormControlElement);
public:
@@ -213,7 +213,7 @@ inline bool isHTMLFormControlElement(const Element& element) {
DEFINE_HTMLELEMENT_TYPE_CASTS_WITH_FUNCTION(HTMLFormControlElement);
DEFINE_TYPE_CASTS(HTMLFormControlElement,
- FormAssociatedElement,
+ ListedElement,
control,
control->isFormControlElement(),
control.isFormControlElement());
@@ -40,10 +40,10 @@ enum CheckValidityEventBehavior {
};
// HTMLFormControlElement is the default implementation of
-// FormAssociatedElement, and form-associated element implementations should use
+// ListedElement, and form-associated element implementations should use
tkent 2016/12/02 13:24:37 form-associated element implementations -> listed
// HTMLFormControlElement unless there is a special reason.

Powered by Google App Engine
This is Rietveld 408576698